@@ -1,21 +1,21 @@
-/* $Id: command-dialog.c 29119 2009-01-10 22:22:24Z jannis $ */
+/* $Id$ */
 /* vi:set sw=2 sts=2 ts=2 et ai: */
 /*-
  * Copyright (c) 2008 Jannis Pohlmann <jannis@xfce.org>.
  *
- * This program is free software; you can redistribute it and/or modify 
- * it under the terms of the GNU General Public License as published by 
- * the Free Software Foundation; either version 2 of the License, or (at 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License 
- * along with this program; if not, write to the Free Software 
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA  02111-1307  USA
  */
 
@@ -26,19 +26,16 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "command-dialog.h"
 
 
 
-static void command_dialog_class_init      (CommandDialogClass *klass);
-static void command_dialog_init            (CommandDialog      *dialog);
-static void command_dialog_dispose         (GObject             *object);
-static void command_dialog_finalize        (GObject             *object);
 static void command_dialog_create_contents (CommandDialog      *dialog,
                                             const gchar        *shortcut,
-                                            const gchar        *action);
+                                            const gchar        *action,
+                                            gboolean            snotify);
 static void command_dialog_button_clicked  (CommandDialog      *dialog);
 
 
@@ -54,54 +51,19 @@ struct _CommandDialog
 
   GtkWidget *entry;
   GtkWidget *button;
+  GtkWidget *sn_option;
 };
 
 
 
-static GObjectClass *command_dialog_parent_class = NULL;
-
-
-
-GType
-command_dialog_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      static const GTypeInfo info = 
-        {
-          sizeof (CommandDialogClass),
-          NULL,
-          NULL,
-          (GClassInitFunc) command_dialog_class_init,
-          NULL,
-          NULL,
-          sizeof (CommandDialog),
-          0,
-          (GInstanceInitFunc) command_dialog_init,
-          NULL,
-        };
-
-      type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "CommandDialog", &info, 0);
-    }
-  
-  return type;
-}
+G_DEFINE_TYPE (CommandDialog, command_dialog, XFCE_TYPE_TITLED_DIALOG)
 
 
 
 static void
 command_dialog_class_init (CommandDialogClass *klass)
 {
-  GObjectClass *gobject_class;
 
-  /* Determine parent type class */
-  command_dialog_parent_class = g_type_class_peek_parent (klass);
-
-  gobject_class = G_OBJECT_CLASS (klass);
-  gobject_class->dispose = command_dialog_dispose;
-  gobject_class->finalize = command_dialog_finalize;
 }
 
 
@@ -115,47 +77,32 @@ command_dialog_init (CommandDialog *dialog)
 
 
 
-static void
-command_dialog_dispose (GObject *object)
-{
-  (*G_OBJECT_CLASS (command_dialog_parent_class)->dispose) (object);
-}
-
-
-
-static void
-command_dialog_finalize (GObject *object)
-{
-  (*G_OBJECT_CLASS (command_dialog_parent_class)->finalize) (object);
-}
-
-
-
 GtkWidget*
 command_dialog_new (const gchar *shortcut,
-                    const gchar *action)
+                    const gchar *action,
+                    gboolean     snotify)
 {
   CommandDialog *dialog;
-  
+
   dialog = COMMAND_DIALOG (g_object_new (TYPE_COMMAND_DIALOG, NULL));
 
-  command_dialog_create_contents (dialog, shortcut, action);
+  command_dialog_create_contents (dialog, shortcut, action, snotify);
 
   return GTK_WIDGET (dialog);
 }
 
 
 
-static void 
+static void
 command_dialog_create_contents (CommandDialog *dialog,
                                 const gchar   *shortcut,
-                                const gchar   *action)
+                                const gchar   *action,
+                                gboolean       snotify)
 {
   GtkWidget *button;
   GtkWidget *table;
   GtkWidget *label;
   GtkWidget *hbox;
-  gchar     *text;
 
   /* Set dialog title and icon */
   gtk_window_set_title (GTK_WINDOW (dialog), _("Shortcut Command"));
@@ -175,7 +122,7 @@ command_dialog_create_contents (CommandDialog *dialog,
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
-  table = gtk_table_new (2, 2, FALSE);
+  table = gtk_table_new (3, 2, FALSE);
   gtk_table_set_row_spacings (GTK_TABLE (table), 6);
   gtk_table_set_col_spacings (GTK_TABLE (table), 12);
   gtk_container_set_border_width (GTK_CONTAINER (table), 6);
@@ -196,7 +143,7 @@ command_dialog_create_contents (CommandDialog *dialog,
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show (label);
-  
+
   hbox = gtk_hbox_new (FALSE, 6);
   gtk_table_attach (GTK_TABLE (table), hbox, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
   gtk_widget_show (hbox);
@@ -212,6 +159,11 @@ command_dialog_create_contents (CommandDialog *dialog,
   gtk_box_pack_start (GTK_BOX (hbox), dialog->button, FALSE, TRUE, 0);
   gtk_widget_show (dialog->button);
 
+  dialog->sn_option = gtk_check_button_new_with_mnemonic (_("Use _startup notification"));
+  gtk_table_attach (GTK_TABLE (table), dialog->sn_option, 1, 2, 2, 3, GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->sn_option), snotify);
+  gtk_widget_show (dialog->sn_option);
+
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 }
 
@@ -226,6 +178,16 @@ command_dialog_get_command (CommandDialog *dialog)
 
 
 
+
+gboolean
+command_dialog_get_snotify (CommandDialog *dialog)
+{
+  g_return_val_if_fail (IS_COMMAND_DIALOG (dialog), FALSE);
+  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->sn_option));
+}
+
+
+
 gint
 command_dialog_run (CommandDialog *dialog,
                     GtkWidget     *parent)
@@ -239,12 +201,12 @@ command_dialog_run (CommandDialog *dialog,
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
-  do 
+  do
     {
       response = gtk_dialog_run (GTK_DIALOG (dialog));
 
       if (G_UNLIKELY (response != GTK_RESPONSE_CANCEL && g_utf8_strlen (command_dialog_get_command (dialog), -1) == 0))
-        xfce_err (_("The command may not be empty."));
+        xfce_dialog_show_error (GTK_WINDOW (dialog), NULL, _("The command may not be empty."));
       else
         finished = TRUE;
     }
@@ -255,7 +217,7 @@ command_dialog_run (CommandDialog *dialog,
 
 
 
-static void 
+static void
 command_dialog_button_clicked (CommandDialog *dialog)
 {
   GtkWidget     *chooser;
@@ -264,9 +226,9 @@ command_dialog_button_clicked (CommandDialog *dialog)
 
   g_return_if_fail (IS_COMMAND_DIALOG (dialog));
 
-  chooser = gtk_file_chooser_dialog_new (_("Select command"), 
-                                         GTK_WINDOW (dialog), 
-                                         GTK_FILE_CHOOSER_ACTION_OPEN, 
+  chooser = gtk_file_chooser_dialog_new (_("Select command"),
+                                         GTK_WINDOW (dialog),
+                                         GTK_FILE_CHOOSER_ACTION_OPEN,
                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                          GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL);
 
