@@ -76,7 +76,7 @@ main (int    argc,
   if (G_UNLIKELY (opt_version))
     {
       g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-      g_print ("%s\n", "Copyright (c) 2008-2010");
+      g_print ("%s\n", "Copyright (c) 2008-2011");
       g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
       g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
       g_print ("\n");
@@ -109,8 +109,16 @@ main (int    argc,
     {
       /* Create and run the settings dialog */
       dialog = xfce_keyboard_settings_create_dialog (settings);
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+
+      gtk_widget_show (GTK_WIDGET (dialog));
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_main_quit), NULL);
+
+      /* To prevent the settings dialog to be saved in the session */
+      gdk_set_sm_client_id ("FAKE ID");
+
+      gtk_main ();
+
+      gtk_widget_destroy (GTK_WIDGET (dialog));
     }
   else
     {
@@ -121,6 +129,9 @@ main (int    argc,
       /* Stop startup notification */
       gdk_notify_startup_complete ();
 
+      /* To prevent the settings dialog to be saved in the session */
+      gdk_set_sm_client_id ("FAKE ID");
+
       /* Enter the main loop */
       gtk_main ();
     }
